aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/example
diff options
context:
space:
mode:
authorGravatar A. Unique TensorFlower <nobody@tensorflow.org>2016-01-05 14:05:27 -0800
committerGravatar Vijay Vasudevan <vrv@google.com>2016-01-05 14:05:27 -0800
commit1c579361cd1e088dd5e05a394b1561a73e3667ba (patch)
treeec464b9ac18113dc052744b6714eebbc7c6cc34d /tensorflow/core/example
parent208350a6092f9faa473daf8b6eb6a80e9f9518f1 (diff)
Added 'logging' import to control_flow_ops which is used in the file but not imported.
Change: 110842260
Diffstat (limited to 'tensorflow/core/example')
-rw-r--r--tensorflow/core/example/example.proto19
-rw-r--r--tensorflow/core/example/feature.proto2
2 files changed, 14 insertions, 7 deletions
diff --git a/tensorflow/core/example/feature.proto b/tensorflow/core/example/feature.proto
index 52d5fac441..130e142503 100644
--- a/tensorflow/core/example/feature.proto
+++ b/tensorflow/core/example/feature.proto
@@ -55,6 +55,8 @@
syntax = "proto3";
// option cc_enable_arenas = true;
+option java_multiple_files = true;
+option java_package = "org.tensorflow.example";
package tensorflow;
diff --git a/tensorflow/core/example/example.proto b/tensorflow/core/example/example.proto
index f4d946dcf0..d2e9f24563 100644
--- a/tensorflow/core/example/example.proto
+++ b/tensorflow/core/example/example.proto
@@ -4,6 +4,8 @@ syntax = "proto3";
import "tensorflow/core/example/feature.proto";
// option cc_enable_arenas = true;
+option java_multiple_files = true;
+option java_package = "org.tensorflow.example";
package tensorflow;
@@ -163,12 +165,13 @@ message Example {
// an empty list (zero length).
// - If a FeatureList L exists, it may be empty (zero length).
// - If a FeatureList L is non-empty, all features within the FeatureList
// must have data type T, and all features within the FeatureList must
// have the same size.
// - If a FeatureList L exists in one example with data type T,
// it must be of type T in all other examples when present.
-// - If a FeatureList L exists in one example having features' sizes all S,
-// these sizes must be S in all other examples when present.
//
// Examples of conformant and non-conformant examples' FeatureLists:
//
@@ -186,7 +189,8 @@ message Example {
// feature: { int64_list: { value: [ 5 ] } } }
// } }
//
-// Non-conformant FeatureLists (mismatched sizes):
+// Conditionally conformant FeatureLists, the parser configuration determines
+// if the feature sizes must match:
// feature_lists: { feature_list: {
// key: "movie_ratings"
// value: { feature: { float_list: { value: [ 4.5 ] } }
@@ -244,7 +248,8 @@ message Example {
// feature: { int64_list: { value: [ 2 ] } } }
// } }
//
-// Non-conformant pair of SequenceExample (mismatched sizes)
+// Conditionally conformant pair of SequenceExample; the parser configuration
+// determines if the feature sizes must match:
// feature_lists: { feature_list: {
// key: "movie_ratings"
// value: { feature: { float_list: { value: [ 4.5 ] } }
@@ -253,7 +258,7 @@ message Example {
// and:
// feature_lists: { feature_list: {
// key: "movie_ratings"
-// value: { feature: { float_list: { value: [ 4.0, 5.0 ] } }
+// value: { feature: { float_list: { value: [ 4.0 ] } }
// feature: { float_list: { value: [ 5.0, 3.0 ] } }
// } }
@@ -163,12 +165,13 @@ message Example {
// - If a FeatureList L exists, it may be empty (zero length).
// - If a FeatureList L is non-empty, all features within the FeatureList
-// must have data type T, and all features within the FeatureList must
-// have the same size.
+// must have data type T.
+// - If a FeatureList L is non-empty, it is up to the parser configuration
+// to determine if all features within the FeatureList must
+// have the same size. The same holds for this FeatureList across multiple
+// examples.
// - If a FeatureList L exists in one example with data type T,
// it must be of type T in all other examples when present.